@@ -1,11 +1,11 @@
 package POE::Component::WebService::Validator::HTML::W3C;
 
-use 5.008008;
-use strict;
 use warnings;
+use strict;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
+use WebService::Validator::HTML::W3C;
 use POE qw( Wheel::Run  Filter::Reference  Filter::Line);
 use Carp;
 
@@ -15,13 +15,6 @@ sub spawn {
     croak "Even number of arguments must be passed to $package"
         if @_ & 1;
 
-    eval {
-        use WebService::Validator::HTML::W3C;
-    };
-
-    croak "Failed to load WebService::Validator::HTML::W3C ($@)"
-        if $@;
-
     my %params = @_;
     
     $params{ lc $_ } = delete $params{ $_ } for keys %params;
@@ -743,15 +736,48 @@ L<POE>, L<WebService::Validator::HTML::W3C>
 
 =head1 AUTHOR
 
-Zoffix Znet, E<lt>zoffix@cpan.orgE<gt> ( L<http://zoffix.com> L<http://haslayout.net> )
+Zoffix Znet, C<< <zoffix at cpan.org> >>
+(L<http://zoffix.com>, L<http://haslayout.net>)
 
-=head1 COPYRIGHT AND LICENSE
+=head1 BUGS
 
-Copyright (C) 2008 by Zoffix Znet
+Please report any bugs or feature requests to C<bug-poe-component-webservice-validator-html-w3c at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=POE-Component-WebService-Validator-HTML-W3C>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.8 or,
-at your option, any later version of Perl 5 you may have available.
+=head1 SUPPORT
 
+You can find documentation for this module with the perldoc command.
+
+    perldoc POE::Component::WebService::Validator::HTML::W3C
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-WebService-Validator-HTML-W3C>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/POE-Component-WebService-Validator-HTML-W3C>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/POE-Component-WebService-Validator-HTML-W3C>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/POE-Component-WebService-Validator-HTML-W3C>
+
+=back
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 Zoffix Znet, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
